# API

## Web API

Import as:

```
from visionpy.api import start_vision
```

```{eval-rst}
.. module:: visionpy.api
.. currentmodule:: visionpy

.. autosummary::
    :toctree: generated

    api.start_vision
```

## Utilities

Import as:

```
import visionpy
```

```{eval-rst}
.. module:: visionpy
.. currentmodule:: visionpy

.. autosummary::
    :toctree: generated

    compute_signatures_anndata
    signatures_from_gmt
```
